# -*- coding: utf-8 -*-
"""
/***************************************************************************
 evacuation Plugin
                                 A QGIS plugin
 QGIS evacuation Plugin
                              -------------------
        begin                : 2020-7-1
        git sha              : $Format:%H$
        copyright            : (C) 2020 by MIERUNE Inc.
        email                : info@mierune.co.jp
        license              : GNU General Public License v2.0
 ***************************************************************************/
"""

import os

from PyQt5.QtCore import *
from PyQt5.QtGui import *
from PyQt5.QtWidgets import *
from qgis.core import *
from qgis.gui import *

# 各ウィンドウを読み込み
from .png2tiff.Png2Tiff import Png2Tiff
from .tiff2png.Tiff2Png import Tiff2Png


class DemConverter:
    def __init__(self, iface):
        self.iface = iface
        self.canvas = self.iface.mapCanvas()

        self.plugin_dir = os.path.dirname(__file__)
        locale = QSettings().value('locale/userLocale')[0:2]
        locale_path = os.path.join(
            self.plugin_dir,
            'i18n',
            'Routlugin{}.qm'.format(locale))
        if os.path.exists(locale_path):
            self.translator = QTranslator()
            self.translator.load(locale_path)
            if qVersion() > '4.3.3':
                QCoreApplication.installTranslator(self.translator)
        self.actions = []

        self.plugin_name = 'DemConverter'
        self.menu = self.plugin_name
        self.toolbar = self.iface.addToolBar(self.plugin_name)
        self.toolbar.setObjectName(self.plugin_name)

    def tr(self, message):
        return QCoreApplication.translate(self.plugin_name, message)

    def add_action(
            self,
            icon_path,
            text,
            callback,
            enabled_flag=True,
            add_to_menu=True,
            add_to_toolbar=True,
            status_tip=None,
            whats_this=None,
            parent=None):
        icon = QIcon(icon_path)
        action = QAction(icon, text, parent)
        action.triggered.connect(callback)
        action.setEnabled(enabled_flag)
        if status_tip is not None:
            action.setStatusTip(status_tip)
        if whats_this is not None:
            action.setWhatsThis(whats_this)
        if add_to_toolbar:
            self.toolbar.addAction(action)
        if add_to_menu:
            self.iface.addPluginToMenu(
                self.menu,
                action)
        self.actions.append(action)
        return action

    def initGui(self):
        self.win = self.iface.mainWindow()
        # メニュー設定
        self.add_action(
            icon_path=None,
            text="TIFFからPNGを切り出し",
            callback=self.open_tiff2png,
            parent=self.win)

        self.add_action(
            icon_path=None,
            text="PNGからTIFFへ変換",
            callback=self.open_png2tiff,
            parent=self.win)

        self.add_action(
            icon_path=None,
            text="ヘルプ",
            callback=self.open_helppage,
            parent=self.win)

    def unload(self):
        for action in self.actions:
            self.iface.removePluginMenu(
                self.plugin_name,
                action)
            self.iface.removeToolBarIcon(action)
        del self.toolbar

    def open_tiff2png(self):
        self.tiff2png = Tiff2Png(self.iface)
        self.tiff2png.dlg.show()

    def open_png2tiff(self):
        self.png2tiff = Png2Tiff(self.iface)
        self.png2tiff.dlg.show()

    def open_helppage(self):
        import webbrowser
        webbrowser.open(os.path.join(
            self.plugin_dir, "helppage", "index.html"))

    def run(self):
        pass
